@@ -9,6 +9,7 @@ Desc:
 '''
 import pandas as pd
 from pynovice.geo_map import GeoMap
+import webbrowser
 
 if __name__ == '__main__':
     df_raw = pd.DataFrame(data= [[-0.4302744, 35.5331974],
@@ -19,4 +20,13 @@ if __name__ == '__main__':
                            columns=['latitude', 'longitude']
                            )
     geo_map = GeoMap()
-    geo_map.run_geo_map(df_raw,web_open=True)
\ No newline at end of file
+    geo_map.set_out_file(html_path='../data/geo.html')
+
+    # 全流程运行
+    # geo_map.run_geo_map(df_raw,web_open=True)
+
+    # 详细的流程
+    df_gps = geo_map.get_geo_reverse(df_raw) #获取geo
+    geo_data = df_gps.groupby("admin1")['lon'].count() #要画图的数据 serios
+    geo_map.plot_geo_summary(geo_data) #生成geo.html 文件
+    webbrowser.open(url='file://' + geo_map.html_name, new=0, autoraise=True) #浏览器打开geo.html文件
\ No newline at end of file
